==> haskell-hscolour-1.24.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hscolour.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hscolour
version: 1.24.2
id: hscolour-1.24.2-2hhTb9jrnCPKmvAsG3oU3G
key: hscolour-1.24.2-2hhTb9jrnCPKmvAsG3oU3G
license: LGPL
copyright: 2003-2017 Malcolm Wallace; 2006 Bjorn Bringert
maintainer: Malcolm Wallace
homepage: http://code.haskell.org/~malcolm/hscolour/
synopsis: Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.
category: Language
author: Malcolm Wallace
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.ANSI Language.Haskell.HsColour.Anchors
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY
abi: 45ac32355cb8fbda7b4c320d66aaf5ae
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hscolour-1.24.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/hscolour-1.24.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-hscolour
hs-libraries: HShscolour-1.24.2-2hhTb9jrnCPKmvAsG3oU3G
depends:
    base-4.10.0.0 containers-0.5.10.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
haddock-interfaces: /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html: /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hscolour-1.24.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hscolour.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hscolour
version: 1.24.4
id: hscolour-1.24.4-1Y3d0ngoISJ82bh0GSbJSM
key: hscolour-1.24.4-1Y3d0ngoISJ82bh0GSbJSM
license: LGPL
copyright: 2003-2017 Malcolm Wallace; 2006 Bjorn Bringert
maintainer: Malcolm Wallace
homepage: http://code.haskell.org/~malcolm/hscolour/
synopsis: Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.
category: Language
author: Malcolm Wallace
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.ANSI Language.Haskell.HsColour.Anchors
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY
abi: af9f57318279320d4866743a502ed206
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hscolour-1.24.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/hscolour-1.24.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-hscolour
hs-libraries: HShscolour-1.24.4-1Y3d0ngoISJ82bh0GSbJSM
depends:
    base-4.10.1.0 containers-0.5.10.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
haddock-interfaces: /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html: /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
